#!/usr/bin/env python

"""
Directory output context.

Copyright (C) 2018 Paul Boddie <paul@boddie.org.uk>

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program.  If not, see <http://www.gnu.org/licenses/>.
"""

from moinformat.output.common import Output
from os.path import abspath, commonprefix, join

def inside(filename, dirname):

    "Return whether 'filename' is inside 'dirname'."

    # Get the directory with trailing path separator.

    dirname = join(dirname, "")
    return commonprefix((filename, dirname)) == dirname



class DirectoryOutput(Output):

    "A directory output context."

    def __init__(self, filename):

        "Initialise the context with the given 'filename'."

        Output.__init__(self)
        self.filename = abspath(filename)

    def get_filename(self, filename):

        "Return a file with the given 'filename' within the directory."

        # Get the absolute path for the combination of directory and filename.

        pathname = abspath(join(self.filename, filename))

        if inside(pathname, self.filename):
            return pathname
        else:
            raise ValueError, filename

# vim: tabstop=4 expandtab shiftwidth=4
